#include <stdio.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/ioctl.h>
#include <machine/ioctl_bt848.h>
#include <machine/ioctl_meteor.h>
#include <unistd.h>

/****************************************************************************/
/*  setchannel.c  -  Set the channel of the bktr tuner card.                */
/*                                                                          */
/*  COMPILE WITH:  cc -o setchannel setchannel.c                            */
/****************************************************************************/

static void
usage()
{
  printf("Usage: setchannel <-a {on|off}|-c|-s|-t|-t channel|channel>\n"
         "  -a  Enable / disable AFC.\n"
         "  -c  Select composite input.\n"
         "  -s  Select svideo input.\n"
         "  -t  Select tuner.\n");
}

int main( int argc, char *argv[] )
{
  int afc;
  int c;
  int status;
  int tfd;
  unsigned int channel;
  unsigned long device;
  
  afc = -1;
  channel = 0;
  device = 0;
  status = 0;

  while ((c = getopt (argc, argv, "a:cst")) != -1)
    switch (c) {
      case 'a':
        if (strcasecmp (optarg, "on") == 0)
          afc = 1;
        else if (strcasecmp (optarg, "off") == 0)
          afc = 0;
        else {
          usage ();
          exit (1);
          }
        break;

      case 'c':
        device = METEOR_INPUT_DEV2;
        break;

      case 's':
        device = METEOR_INPUT_DEV_SVIDEO;
        break;

      case 't':
        device = METEOR_INPUT_DEV1;
        break;

      default:
        usage ();
        exit (1);
    }

  if ( optind < argc)
    channel = atoi( argv[optind] );

  if (afc == -1 && ! channel && ! device) {
    usage ();
    exit (1);
    }

  tfd = open( "/dev/bktr0", O_RDONLY );
  if ( tfd < 0 ) {
    perror( "open() of /dev/bktr0 failed." );
    exit(1);
  }

  if (afc != -1)
    if ( ioctl( tfd, TVTUNER_SETAFC, &afc ) < 0 ) {
      perror( "ioctl( tfd, TVTUNER_SETAFC ) failed." );
      status = 1;
    }

  if (device)
    if ( ioctl( tfd, METEORSINPUT, &device ) < 0 ) {
      perror( "ioctl( tfd, METEORSINPUT ) failed." );
      status = 1;
    }

  if (channel)
    if ( ioctl( tfd, TVTUNER_SETCHNL, &channel ) < 0 ) {
      perror( "ioctl( tfd, TVTUNER_SETCHNL ) failed." );
      status = 1;
    }

  close ( tfd );
  exit ( status );
}
